@@ -438,7 +438,7 @@ class JSONDisplay(DisplayData):
         """Render the JSON display data."""
         rendered_json = syntax.Syntax(
             self.content,
-            lexer_name="json",
+            lexer="json",
             theme=self.theme,
             background_color="default",
         )
@@ -572,7 +572,6 @@ def _choose_basic_renderer(
 def render_display_data(
     data: Data,
     unicode: bool,
-    plain: bool,
     nerd_font: bool,
     theme: str,
     images: bool,
